@@ -20,6 +20,11 @@
 #include <bonobo/bonobo-control-internal.h>
 #include <libgnome/gnome-macros.h>
 
+
+/* Used to turn on any socket sizing
+ * bits layered over gtk we have */
+#undef DEBUG_RAW_GTK
+
 GNOME_CLASS_BOILERPLATE (BonoboSocket, bonobo_socket,
 			 GObject, GTK_TYPE_SOCKET);
 
@@ -93,6 +98,10 @@ static gboolean
 bonobo_socket_expose_event (GtkWidget      *widget,
 			    GdkEventExpose *event)
 {
+	gboolean retval;
+
+	retval = GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
+
 	dprintf ("bonobo_socket_expose_event %p (%d, %d), (%d, %d)\n",
 		 widget,
 		 event->area.x, event->area.y,
@@ -106,7 +115,7 @@ bonobo_socket_expose_event (GtkWidget      *widget,
 		       event->area.y + event->area.height);
 #endif
 
-	return FALSE;
+	return retval;
 }
 
 static void
@@ -159,10 +168,13 @@ static void
 bonobo_socket_size_allocate (GtkWidget     *widget,
 			     GtkAllocation *allocation)
 {
-	dprintf ("bonobo_socket_size_allocate: (%d, %d), (%d, %d)\n",
-		 allocation->x, allocation->y,
-		 allocation->width, allocation->height);
-	
+	GtkSocket *socket = (GtkSocket *) widget;
+
+	dprintf ("bonobo_socket_size_allocate %p: (%d, %d), (%d, %d), %p, %p\n",
+		 widget, allocation->x, allocation->y,
+		 allocation->width, allocation->height,
+		 socket->plug_widget, socket->plug_window);
+
 	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
 }
 
@@ -173,18 +185,25 @@ bonobo_socket_size_request (GtkWidget      *widget,
 	BonoboSocket *socket = (BonoboSocket *) widget;
 	GtkSocket    *gtk_socket = (GtkSocket *) widget;
 
+	dprintf ("pre bonobo_socket_size_request %p: realized %d, %s frame, %d %d\n",
+		 widget, GTK_WIDGET_REALIZED (widget) ? 1:0,
+		 socket->frame ? "has" : "no",
+		 gtk_socket->is_mapped, gtk_socket->have_size);
+
+#ifndef DEBUG_RAW_GTK
 	if (GTK_WIDGET_REALIZED (widget) ||
 	    !socket->frame ||
 	    (gtk_socket->is_mapped && gtk_socket->have_size))
-
+#endif
 		GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_request,
 				   (widget, requisition));
 
+#ifndef DEBUG_RAW_GTK
 	else if (gtk_socket->have_size &&
 		 GTK_WIDGET_VISIBLE (gtk_socket)) {
 
 		requisition->width = gtk_socket->request_width;
-		requisition->width = gtk_socket->request_height;
+		requisition->height = gtk_socket->request_height;
 
 	} else {
 		CORBA_Environment tmp_ev, *ev;
@@ -197,14 +216,30 @@ bonobo_socket_size_request (GtkWidget      *widget,
 		if (!BONOBO_EX (ev)) {
 			gtk_socket->have_size = TRUE;
 			gtk_socket->request_width = requisition->width;
-			gtk_socket->request_height = requisition->width;
+			gtk_socket->request_height = requisition->height;
 		}
 
 		CORBA_exception_free (ev);
 	}
+#endif
 
-	dprintf ("bonobo_socket_size_request: %d, %d\n",
-		 requisition->width, requisition->height);
+	dprintf ("bonobo_socket_size_request %p: %d, %d\n",
+		 widget, requisition->width, requisition->height);
+}
+
+static void
+bonobo_socket_show (GtkWidget *widget)
+{
+	dprintf ("bonobo_socket_show %p\n", widget);
+
+	/* We do a check_resize here, since if we're in-proc we
+	 * want to force a size_allocate on the contained GtkPlug,
+	 * before we go and map it (waiting for the idle resize),
+	 * since idle can be held off for a good while, and cause
+	 * extreme ugliness and flicker */
+	gtk_container_check_resize (GTK_CONTAINER (widget));
+
+	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, show, (widget));
 }
 
 static void
@@ -244,6 +279,7 @@ bonobo_socket_class_init (BonoboSocketClass *klass)
 	widget_class->size_request    = bonobo_socket_size_request;
 	widget_class->size_allocate   = bonobo_socket_size_allocate;
 	widget_class->expose_event    = bonobo_socket_expose_event;
+	widget_class->show            = bonobo_socket_show;
 	widget_class->show_all        = bonobo_socket_show_all;
 
 	socket_class->plug_removed    = bonobo_socket_plug_removed;
@@ -302,3 +338,26 @@ bonobo_socket_set_control_frame (BonoboSocket       *socket,
 	if (frame)
 		bonobo_control_frame_set_socket (frame, socket);
 }
+
+void
+bonobo_socket_add_id (BonoboSocket   *socket,
+		      GdkNativeWindow xid)
+{
+	GtkSocket *gtk_socket = (GtkSocket *) socket;
+
+	gtk_socket_add_id (gtk_socket, xid);
+
+	/* The allocate didn't get through even to the in-proc case,
+	 * so do it again */
+	if (gtk_socket->plug_widget) {
+		GtkAllocation child_allocation;
+
+		child_allocation.x = 0;
+		child_allocation.y = 0;
+		child_allocation.width = GTK_WIDGET (gtk_socket)->allocation.width;
+		child_allocation.height = GTK_WIDGET (gtk_socket)->allocation.height;
+		
+		gtk_widget_size_allocate (gtk_socket->plug_widget,
+					  &child_allocation);
+	}
+}
