@@ -350,7 +350,7 @@ main (int argc, char **argv)
 	if (fname && g_file_test (fname, G_FILE_TEST_EXISTS)) {
 		fprintf (stderr, "\n\n--- Add std-ui.xml ---\n\n\n");
 		bonobo_ui_util_set_ui (componenta, NULL, "../doc/std-ui.xml",
-				       "gnomecal", NULL);
+				       "gdm", NULL);
 
 /*		bonobo_ui_component_set_prop (
 			componenta, "/menu/Preferences",
@@ -414,6 +414,7 @@ main (int argc, char **argv)
 		g_assert (!BONOBO_EX (ev));
 	}
 
+#ifdef OLD_STUFF
 	{
 		GtkWidget *widget = gtk_entry_new ();
 		BonoboControl *control = bonobo_control_new (widget);
@@ -427,6 +428,18 @@ main (int argc, char **argv)
 		bonobo_object_unref (BONOBO_OBJECT (control));
 		g_assert (!BONOBO_EX (ev));
 	}
+#else
+	{
+		GtkWidget *widget = gtk_entry_new ();
+		
+		gtk_entry_set_text (GTK_ENTRY (widget), "Example text");
+		gtk_widget_show (widget);
+		bonobo_ui_component_widget_set (componenta,
+						"/Toolbar/AControl",
+						widget, ev);
+		g_assert (!BONOBO_EX (ev));
+	}
+#endif
 
 	bonobo_ui_component_add_listener (componentb, "MyFoo", toggled_cb, ev);
 	g_assert (!BONOBO_EX (ev));
